import * as vscode from 'vscode';

export function activate(context: vscode.ExtensionContext) {

	let disposable = vscode.languages.registerInlineValuesProvider('javascript', {

		provideInlineValues(document: vscode.TextDocument, viewport: vscode.Range, context: vscode.InlineValueContext)
						: vscode.ProviderResult<vscode.InlineValue[]> {

			const allValues: vscode.InlineValue[] = [];

			for (let l = viewport.start.line; l <= context.stoppedLocation.end.line; l++) {
				const line = document.lineAt(l);

				var regExp = /[A-Z]+/g;
				var match;
				do {
					match = regExp.exec(line.text);
					if (match) {
						const varName = match[0];
						const varRange = new vscode.Range(l, match.index, l, match.index + varName.length);

						//const iv = new vscode.InlineValueText(varRange, `${varName}: s:${varRange.start.character} e:${varRange.end.character}`);
						const iv = new vscode.InlineValueVariableLookup(varRange);
						//const iv = new vscode.InlineValueEvaluatableExpression(varRange, varName);

						allValues.push(iv);
					}
				} while (match);
			}

			return allValues;
		}
	});

	context.subscriptions.push(disposable);
}

// this method is called when your extension is deactivated
export function deactivate() {}
